.. _installation:

Installing peewee
=================

Most users will want to simply install the latest version, hosted on PyPI:

.. code-block:: console

    pip install peewee


Installing Manually
-------------------

The project is hosted at https://github.com/coleifer/peewee and can be installed
manually:

.. code-block:: console

    git clone https://github.com/coleifer/peewee.git
    cd peewee
    python setup.py install


Running tests
-------------

You can test your installation by running the test suite.

.. code-block:: console

    python setup.py test
